@@ -128,7 +128,7 @@ int main(int argc, char *argv[])
 
   // Set up some behaviours to handle scaling
   Glib::RefPtr<Clutter::Alpha> alpha =
-    Clutter::Alpha::create(timeline, Clutter::ALPHA_SINE);
+    Clutter::Alpha::create(timeline, Clutter::EASE_IN_SINE);
 
   Glib::RefPtr<Clutter::BehaviourScale> scaler_1 =
     Clutter::BehaviourScale::create(alpha,
@@ -165,7 +165,7 @@ int main(int argc, char *argv[])
     }
     else
     {
-      oh.hands.push_back(Clutter::CloneTexture::create
+      oh.hands.push_back(Clutter::Clone::create
         (Glib::RefPtr<Clutter::Texture>::cast_dynamic
           (oh.hands[0])));
     }
